log

package
v0.0.0-...-b56184e Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 8, 2021 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Fail

func Fail(format string, v ...interface{})

Fail logs a message with a [ FAIL ] prefix.

func Fatalf

func Fatalf(format string, v ...interface{})

Fatalf will log a message with a given format and [ FATAL ] prefix then exit.

func Fatalln

func Fatalln(v ...interface{})

Fatalf will log a message with a new line and [ FATAL ] prefix then exit.

func Ok

func Ok(format string, v ...interface{})

Ok logs a message with an [ OK ] prefix.

func Prefix

func Prefix(code ansi.EscapeCode, msg string) string

Prefix creates a custom log Prefix. Example: [ OK ], [ WARN ], [ BAD ]

func PrefixPrintf

func PrefixPrintf(prefix string, format string, v ...interface{})

PrefixPrintf will log a message with a given prefix and format.

func Printf

func Printf(format string, v ...interface{})

Printf will log a message with a given format and [ LOG ] prefix

func Println

func Println(v ...interface{})

Println will log a message with a new line and prefx [ LOG ].

func Warning

func Warning(format string, v ...interface{})

Warning logs a message with a [ WARN ] prefix.

Types

This section is empty.

Directories

Path Synopsis

Jump to