Documentation
¶
Index ¶
- func Fail(format string, v ...interface{})
- func Fatalf(format string, v ...interface{})
- func Fatalln(v ...interface{})
- func Ok(format string, v ...interface{})
- func Prefix(code ansi.EscapeCode, msg string) string
- func PrefixPrintf(prefix string, format string, v ...interface{})
- func Printf(format string, v ...interface{})
- func Println(v ...interface{})
- func Warning(format string, v ...interface{})
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Fatalf ¶
func Fatalf(format string, v ...interface{})
Fatalf will log a message with a given format and [ FATAL ] prefix then exit.
func Fatalln ¶
func Fatalln(v ...interface{})
Fatalf will log a message with a new line and [ FATAL ] prefix then exit.
func Prefix ¶
func Prefix(code ansi.EscapeCode, msg string) string
Prefix creates a custom log Prefix. Example: [ OK ], [ WARN ], [ BAD ]
func PrefixPrintf ¶
PrefixPrintf will log a message with a given prefix and format.
func Printf ¶
func Printf(format string, v ...interface{})
Printf will log a message with a given format and [ LOG ] prefix
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.